Frequently asked questions
==========================


What's included in a 'typical' |MESSAGEix| model?
-------------------------------------------------

A typical |MESSAGEix| model instance is based on a suite of technologies such as power plants, which represent a reference energy system (RES).
Each technology is characterised by its input and output commodities, costs (investment, fixed and variable components), and other technical/engineering parameters.
The model minimizes the total system cost while meeting a given demand for energy services or commodities.


Which policies and regulatory measures can be included?
-------------------------------------------------------

The |MESSAGEix| framework can represent a wide range of mitigation options and policies to analyse transformation pathways.
For example, bounds or taxes on emissions can be defined to shift the system towards a low-emission technology mix.
Upper or lower bounds on deployment of new technologies can also be easily included.


Answered elsewhere
------------------
- Under which license is |MESSAGEix| released? → see ``README.md`` or the :doc:`the documentation index <index>`.
- Can I use |MESSAGEix| for my own analysis? → see :doc:`notice`.
- How can I contribute to the development of the |MESSAGEix| framework? → see :doc:`contributing`.
- I have a question not answered here → see :doc:`the documentation index <index>` for information on the community mailing list.
